@@ -45,12 +45,12 @@ class RestAPI(object):
 			# the timestamps.
 			"timestamps": {
 				"signed_up":None,
-			}
+			},
 			# the requests.
 			"requests": {
 				"rate":0,
 				"timestamp":0,
-			}
+			},
 			# the permissions,
 			"permissions": {
 				"email":True,
@@ -438,6 +438,10 @@ class RestAPI(object):
 
 		#
 	def set_email_permission(self, uid, permission=True):
+		return self.set_permission(uid, "email", permission=permission)
+
+		#
+	def set_permission(self, uid, permission_id, permission=True):
 		
 		# load user data.
 		reference = f"users/{uid}"
@@ -446,14 +450,14 @@ class RestAPI(object):
 		data = response["document"]
 
 		# edit data.
-		data["email_permission"] = permission
+		data["permissions"][permission_id] = permission
 
 		# save data.
 		response = self.firebase.firestore.save(reference, data) 
 		if response["error"] != None: return response
 
 		# handlers.
-		return r3sponse.success_response(f"Successfully set the email permission of user [{uid}] to [{permission}].")
+		return r3sponse.success_response(f"Successfully set the {permission_id} permission of user [{uid}] to [{permission}].")
 
 	# requests & rate limit functions.
 	def verify_rate_limit(self, 
@@ -487,7 +491,7 @@ class RestAPI(object):
 		date = Formats.Date()
 
 		# check trial.
-		if trial and data["signed_up"] == date.date:
+		if trial and data["timestamps"]["signed_up"] == date.date:
 			return r3sponse.success_response("Successfully verified the rate limit.")
 
 		# check timestamp.
@@ -572,7 +576,7 @@ class RestAPI(object):
 		data = ast.literal_eval(str(self.__default_user_data__))
 
 		# set signed up timestamp.
-		data["signed_up"] = Formats.Date().date
+		data["timestamps"]["signed_up"] = Formats.Date().date
 
 		# generate api key.
 		response = self.__generate_key__()
@@ -602,8 +606,8 @@ class RestAPI(object):
 			edits += 1
 
 		# test signed up stamp.
-		if data["signed_up"] == None:
-			data["signed_up"] = Formats.Date().date
+		if data["timestamps"]["signed_up"] == None:
+			data["timestamps"]["signed_up"] = Formats.Date().date
 			edits += 1
 
 		# test api key.
